cat > $1/configure.ac <<EOF
AC_INIT([$2], [0.0.0], [$3], [$1])
AC_CONFIG_HEADERS(config.h)
AM_INIT_AUTOMAKE(no-dist-gzip dist-bzip2)

# Checks for programs.
AC_PROG_CC
EOF
if [[ -n $4 ]]
then echo "AM_PROG_CC_C_O" >> $1/configure.ac
fi
cat >> $1/configure.ac <<EOF

# Checks for libraries.
EOF
if [[ -n $4 ]]
then
	cat >> $1/configure.ac <<-EOF
	DEP_MODULES="$4"
	PKG_CHECK_MODULES(DEPS, \$DEP_MODULES)
	AC_SUBST(DEPS_CFLAGS)
	AC_SUBST(DEPS_LIBS)
	EOF
fi
cat >> $1/configure.ac <<EOF

# Checks for header files.
AC_STDC_HEADERS

# Checks for typedefs, structures, and compiler characteristics.

# Checks for library functions.

AC_CONFIG_FILES([Makefile src/Makefile])
AC_OUTPUT
EOF
